# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,hzr_stepwise)
S3method(coef,hazard)
S3method(predict,hazard)
S3method(print,hazard)
S3method(print,hzr_bootstrap)
S3method(print,hzr_calibrate)
S3method(print,hzr_competing_risks)
S3method(print,hzr_deciles)
S3method(print,hzr_gof)
S3method(print,hzr_kaplan)
S3method(print,hzr_nelson)
S3method(print,hzr_phase)
S3method(print,hzr_stepwise)
S3method(print,summary.hazard)
S3method(print,summary.hzr_stepwise)
S3method(summary,hazard)
S3method(summary,hzr_stepwise)
S3method(vcov,hazard)
export(hazard)
export(hzr_argument_mapping)
export(hzr_bootstrap)
export(hzr_calibrate)
export(hzr_clamp_prob)
export(hzr_competing_risks)
export(hzr_deciles)
export(hzr_decompos)
export(hzr_decompos_g3)
export(hzr_gof)
export(hzr_kaplan)
export(hzr_log1mexp)
export(hzr_log1pexp)
export(hzr_nelson)
export(hzr_phase)
export(hzr_phase_cumhaz)
export(hzr_phase_hazard)
export(hzr_stepwise)
export(is_hzr_phase)
export(stepwise_trace)
importFrom(stats,dnorm)
importFrom(stats,optim)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,setNames)
importFrom(survival,Surv)
importFrom(utils,read.table)
importFrom(utils,write.csv)
