% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/math_primitives.R
\name{hzr_clamp_prob}
\alias{hzr_clamp_prob}
\title{Clamp probabilities away from 0 and 1}
\usage{
hzr_clamp_prob(p, eps = 1e-12)
}
\arguments{
\item{p}{Numeric vector of probabilities.}

\item{eps}{Small positive tolerance.}
}
\value{
Numeric vector bounded to \verb{[eps, 1 - eps]}.
}
\description{
Clamp probabilities away from 0 and 1
}
\examples{
hzr_clamp_prob(c(0, 0.5, 1))
}
