% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict-cl.R
\name{.hzr_predict_cl_from_se}
\alias{.hzr_predict_cl_from_se}
\title{Apply a scale transform + back-transform for CLs}
\usage{
.hzr_predict_cl_from_se(fit, se_nat, level, scale)
}
\arguments{
\item{fit}{Point estimate (numeric vector length n).}

\item{se_nat}{SE on the natural scale (numeric vector length n).}

\item{level}{Confidence level.}

\item{scale}{One of "natural", "log", "loglog_survival".}
}
\value{
data.frame with columns fit, se.fit, lower, upper.
}
\description{
Apply a scale transform + back-transform for CLs
}
\keyword{internal}
