% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/decomposition.R
\name{.log1pexp}
\alias{.log1pexp}
\title{Compute log(1 + exp(x)) with overflow/underflow protection}
\usage{
.log1pexp(x)
}
\arguments{
\item{x}{Numeric vector.}
}
\value{
Numeric vector: log(1 + exp(x)).
}
\description{
Compute log(1 + exp(x)) with overflow/underflow protection
}
\keyword{internal}
