% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict-cl.R
\name{.hzr_predict_se_from_jacobian}
\alias{.hzr_predict_se_from_jacobian}
\title{Per-row standard errors via the delta method}
\usage{
.hzr_predict_se_from_jacobian(J, vcov)
}
\arguments{
\item{J}{Jacobian (n x p).}

\item{vcov}{p x p variance-covariance matrix.}
}
\value{
Numeric vector of length n.
}
\description{
Per-row standard errors via the delta method
}
\keyword{internal}
