% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{omc}
\alias{omc}
\title{OMC: Open Mitral Commissurotomy}
\format{
A data frame with 339 rows and 7 variables:
\describe{
\item{study}{Patient identifier}
\item{te1}{Indicator for first thromboembolic event}
\item{te2}{Indicator for second thromboembolic event}
\item{te3}{Indicator for third thromboembolic event}
\item{int_dead}{Follow-up interval to death or last contact (months)}
\item{dead}{Death indicator (1 = dead, 0 = censored)}
\item{opdjul}{Operation date (Julian)}
}
}
\source{
University of Alabama Birmingham cardiac surgery registry.
}
\usage{
omc
}
\description{
Data for 339 patients who underwent open mitral commissurotomy at the
University of Alabama Birmingham. Contains repeated thromboembolic events
(up to 3 per patient) with left censoring, exercising the interval
censoring likelihood.
}
\seealso{
Other datasets:
\code{\link{avc}},
\code{\link{cabgkul}},
\code{\link{tga}},
\code{\link{valves}}
}
\concept{datasets}
\keyword{datasets}
