% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict-cl.R
\name{.hzr_predict_jacobian_numeric}
\alias{.hzr_predict_jacobian_numeric}
\title{Numeric Jacobian of a single-distribution prediction w.r.t. theta}
\usage{
.hzr_predict_jacobian_numeric(predict_fn, theta)
}
\arguments{
\item{predict_fn}{Function(theta) -> numeric vector of length n.}

\item{theta}{MLE parameter vector.}
}
\value{
Numeric n x p Jacobian.
}
\description{
Numeric Jacobian of a single-distribution prediction w.r.t. theta
}
\keyword{internal}
