% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict-cl.R
\name{.hzr_predict_jacobian_weibull}
\alias{.hzr_predict_jacobian_weibull}
\title{Jacobian of Weibull predictions with respect to theta}
\usage{
.hzr_predict_jacobian_weibull(type, theta, time, x, p)
}
\arguments{
\item{type}{Prediction type (see \code{.hzr_predict_with_se}).}

\item{theta}{MLE parameter vector \code{c(mu, nu, beta_1, ...)}.}

\item{time}{Prediction times (may be NULL for \code{hazard} / \code{linear_predictor}).}

\item{x}{Design matrix (n x p_cov) or NULL.}

\item{p}{Length of theta.}
}
\value{
Numeric n x p Jacobian.
}
\description{
Jacobian of Weibull predictions with respect to theta
}
\keyword{internal}
