% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{valves}
\alias{valves}
\title{Valves: Primary Heart Valve Replacement}
\format{
A data frame with 1533 rows and 19 variables:
\describe{
\item{age_cop}{Age at operation (years)}
\item{nyha}{NYHA functional class (1--4)}
\item{mitral}{Mitral valve position indicator (0/1)}
\item{double_}{Double valve replacement indicator (0/1)}
\item{ao_pinc}{Aortic position, incompetence (0/1)}
\item{black}{Black race indicator (0/1)}
\item{i_path}{Ischemic pathology indicator (0/1)}
\item{nve}{Native valve endocarditis indicator (0/1)}
\item{mechvalv}{Mechanical valve indicator (0/1)}
\item{male}{Male sex indicator (0/1)}
\item{int_dead}{Follow-up interval to death or last contact (months)}
\item{dead}{Death indicator (1 = dead, 0 = censored)}
\item{int_pve}{Follow-up interval to PVE or last contact (months)}
\item{pve}{PVE indicator (1 = PVE, 0 = censored)}
\item{bio}{Bioprosthesis indicator (0/1)}
\item{int_rdg}{Follow-up interval to degeneration or last contact (months)}
\item{reop_dg}{Reoperation for degeneration indicator (0/1)}
\item{int_reop}{Follow-up interval to reoperation or last contact (months)}
\item{reop}{Reoperation indicator (0/1)}
}
}
\source{
Cleveland Clinic Foundation heart valve replacement registry.
}
\usage{
valves
}
\description{
Data for 1,533 patients who underwent primary heart valve replacement.
The largest multivariable example dataset with multiple endpoints
including death, prosthetic valve endocarditis (PVE), bioprosthesis
degeneration, and reoperation.
}
\examples{
data(valves)
valves_cc <- na.omit(valves)

# Kaplan-Meier for two endpoints
km_death <- survival::survfit(
  survival::Surv(int_dead, dead) ~ 1, data = valves_cc)
km_pve <- survival::survfit(
  survival::Surv(int_pve, pve) ~ 1, data = valves_cc)

plot(km_death, xlab = "Months after valve replacement", ylab = "Survival",
     main = "Valves: Death and PVE endpoints")
lines(km_pve, col = "red")
legend("bottomleft", c("Death", "PVE"), col = c("black", "red"), lty = 1)

}
\seealso{
\code{vignette("fitting-hazard-models")},
\code{vignette("prediction-visualization")}

Other datasets:
\code{\link{avc}},
\code{\link{cabgkul}},
\code{\link{omc}},
\code{\link{tga}}
}
\concept{datasets}
\keyword{datasets}
