% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/likelihood-multiphase.R
\name{.hzr_log_mu_positions}
\alias{.hzr_log_mu_positions}
\title{Find the position of each phase's log_mu in the full theta vector}
\usage{
.hzr_log_mu_positions(phases, covariate_counts)
}
\arguments{
\item{phases}{Named list of validated \code{hzr_phase} objects.}

\item{covariate_counts}{Named integer vector of per-phase covariate counts.}
}
\value{
Named integer vector: position of log_mu for each phase.
}
\description{
Find the position of each phase's log_mu in the full theta vector
}
\keyword{internal}
