% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/likelihood-multiphase.R
\name{.hzr_unpack_phase_theta}
\alias{.hzr_unpack_phase_theta}
\title{Extract parameters from a phase sub-vector (internal scale)}
\usage{
.hzr_unpack_phase_theta(theta_j, phase)
}
\arguments{
\item{theta_j}{Numeric sub-vector for one phase.}

\item{phase}{An \code{hzr_phase} object.}
}
\value{
Named list with \code{log_mu}, \code{log_t_half}, \code{nu}, \code{m}, \code{beta}.
}
\description{
Extract parameters from a phase sub-vector (internal scale)
}
\keyword{internal}
