% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/decomposition.R
\name{.log_expm1}
\alias{.log_expm1}
\title{Compute log(exp(x) - 1) with numerical stability}
\usage{
.log_expm1(x)
}
\arguments{
\item{x}{Numeric vector (must be > 0 for exp(x) > 1).}
}
\value{
Numeric vector: log(exp(x) - 1).
}
\description{
Compute log(exp(x) - 1) with numerical stability
}
\keyword{internal}
